@@ -2,14 +2,10 @@
 #' 
 #' Read tabular data from the clipboard.
 #' 
-#' @author Stephen Turner
-#' @keywords keywords
-#' 
 #' @param header A logical value indicating whether the file contains the names of the variables as its first line. Overrides the default \code{header=FALSE} option in \code{read.table()}.
 #' @param ... Further arguments to be passed to \code{read.table}
 #' 
 #' @return A data.frame
-#' @import utils
 #' 
 #' @examples
 #' \dontrun{
@@ -23,6 +19,6 @@ read.cb <- function(header=TRUE, ...) {
     if (os=="Darwin")       content <- read.table(pipe("pbpaste"),  header=header, ...)
     else if (os=="Windows") content <- read.table(file="clipboard", header=header, ...)
     else stop("Sorry, only works on Windows and Mac.")
-    if ("package:dplyr" %in% search()) content <- tbl_df(content)
+    content <- tibble::as_tibble(content)
     return(content)
 }
\ No newline at end of file
